<?php
/**
 * Hungarian language file
 *
 * @author Sandor TIHANYI <stihanyi+dw@gmail.com>
 * @author Siaynoq Mage <siaynoqmage@gmail.com>
 * @author schilling.janos@gmail.com
 * @author Szabó Dávid <szabo.david@gyumolcstarhely.hu>
 * @author Sándor TIHANYI <stihanyi+dw@gmail.com>
 * @author David Szabo <szabo.david@gyumolcstarhely.hu>
 */
$lang['menu']                  = 'Bővítménykezelő';
$lang['download']              = 'Új bővítmény letöltése és telepítése';
$lang['manage']                = 'Telepített bővítmények';
$lang['btn_info']              = 'infó';
$lang['btn_update']            = 'frissítés';
$lang['btn_delete']            = 'törlés';
$lang['btn_settings']          = 'beállítások';
$lang['btn_download']          = 'Letöltés';
$lang['btn_enable']            = 'Mentés';
$lang['url']                   = 'URL:';
$lang['installed']             = 'Telepítve:';
$lang['lastupdate']            = 'Utolsó frissítés:';
$lang['source']                = 'Forrás:';
$lang['unknown']               = 'ismeretlen';
$lang['updating']              = 'Frissítés...';
$lang['updated']               = 'A %s bővítmény sikeresen frissült.';
$lang['updates']               = 'A következő bővítmények sikeresen frissültek:';
$lang['update_none']           = 'Nem találtam újabb verziót.';
$lang['deleting']              = 'Törlés...';
$lang['deleted']               = 'A %s bővítményt eltávolítottam.';
$lang['downloading']           = 'Letöltés...';
$lang['downloaded']            = 'A %s bővítmény sikeresen feltelepült.';
$lang['downloads']             = 'A következő bővítmények sikeresen feltelepültek:';
$lang['download_none']         = 'Nem találtam bővítményt, vagy ismeretlen hiba történt a letöltés/telepítés közben.';
$lang['plugin']                = 'Bővítmény:';
$lang['components']            = 'Részek';
$lang['noinfo']                = 'Ez a bővítmény nem tartalmaz infót, lehet, hogy hibás.';
$lang['name']                  = 'Név:';
$lang['date']                  = 'Dátum:';
$lang['type']                  = 'Típus:';
$lang['desc']                  = 'Leírás:';
$lang['author']                = 'Szerző:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'Ismeretlen hiba lépett fel.';
$lang['error_download']        = 'Nem tudom letölteni a bővítmény fájlt: %s';
$lang['error_badurl']          = 'Feltehetően rossz URL - nem tudom meghatározni a fájlnevet az URL-ből.';
$lang['error_dircreate']       = 'Nem tudom létrehozni az átmeneti könyvtárat a letöltéshez.';
$lang['error_decompress']      = 'A Bővítménykezelő nem tudta a letöltött állományt kicsomagolni. Ennek oka lehet hibás letöltés, ebben az esetben újra letöltéssel próbálkozhatsz, esetleg a tömörítés módja ismeretlen, ebben az esetben kézzel kell letölteni és telepíteni a bővítményt.';
$lang['error_copy']            = 'Fájl másolási hiba történt a(z) <em>%s</em> bővítmény telepítése közben: vagy a lemezterület fogyott el, vagy az állomány hozzáférési jogosultságok nem megfelelőek. Emiatt előfordulhat, hogy a bővítményt csak részben sikerült telepíteni, és a wiki összeomolhat.';
$lang['error_delete']          = 'Hiba történt a(z) <em>%s</em> bővítmény eltávolítása közben. A legvalószínűbb ok, hogy a könyvtár vagy állomány hozzáférési jogosultságok nem megfelelőek.';
$lang['enabled']               = 'A(z) %s bővítmény bekapcsolva.';
$lang['notenabled']            = 'A(z) %s bővítmény engedélyezése nem sikerült. Ellenőrizze a fájl-hozzáférési engedélyeket.';
$lang['disabled']              = 'A(z) %s bővítmény kikapcsolva.';
$lang['notdisabled']           = 'A(z) %s bővítmény kikapcsolása nem sikerült. Ellenőrizze a fájl-hozzáférési engedélyeket.';
$lang['packageinstalled']      = 'A bővítmény csomag(ok) feltelepült(ek): %d plugin(s): %s';
